/*  common.c - Functions used throughout the program
 *  Copyright (C) 2001 Kristof Verniers
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <mysql.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "ts.h"

int get_db_connection(MYSQL *mysql)
{
  // initialize structure
  mysql_init(mysql);

  // connect to the database
  if (!mysql_real_connect(mysql, config.host, config.user, config.passwd, config.db, config.port, NULL, 0)) {
    fprintf(stderr, "Unable to connect to the database: %s.\n", mysql_error(mysql));
    return FAILURE;
  }

  return SUCCESS;
}

void close_db_connection(MYSQL *mysql)
{
  mysql_close(mysql);
}

void prepare(MYSQL *mysql, char *to, char *from, int size)
{
  char *escaped;

  escaped = (char *) malloc(strlen(from)*2+1);
  mysql_real_escape_string(mysql, escaped, from, strlen(from));
  strncpy(to, escaped, size);
  to[size] = '\0';
}

void print_padded(char *str, int length)
{
  int i;
  
  for (i = 0; i < length-strlen(str); i++) 
    printf(" ");
  printf("%s", str);

}

long returns_rows(MYSQL *mysql, char *query)
{
  MYSQL_RES *result;
  int rows;

  if (mysql_query(mysql, query)) {
    fprintf(stderr, "Problem while running query: %s.\n", mysql_error(mysql));
    return FAILURE;
  }

  result = mysql_store_result(mysql);
  rows = mysql_num_rows(result);
  free(result);
 
  return rows;
}

long get_date(MYSQL *mysql, char *date) {
  MYSQL_RES *result;
  MYSQL_ROW row;
  char query[1000];
  long converted_date;
	
  sprintf(query, "select unix_timestamp('%s')", date);
  if (mysql_query(mysql, query)) {
    fprintf(stderr, "Problem while running query: %s.\n", mysql_error(mysql));
    return -1;
  }
  result = mysql_store_result(mysql);
  converted_date = -1;
  if ((row = mysql_fetch_row(result))) {
    converted_date = atol(*row); 
  }
  free(result);
  
  return converted_date;
}
