/*  customers.c - Functions for dealing with customers.
 *  Copyright (C) 2001 Kristof Verniers
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <mysql.h>
#include <stdio.h>
#include <stdlib.h>
#include "ts.h"

int run_select_query(MYSQL *mysql, char *query, char *norecords)
{
  MYSQL_ROW row;
  MYSQL_RES *result;
  int count = 0;
  int ok = TRUE;
	
  if (mysql_query(mysql, query)) {
    fprintf(stderr, "Problem while running query: %s.\n", mysql_error(mysql));
    return FAILURE;
  }

  result = mysql_use_result(mysql);

  //read in result
  while ((row = mysql_fetch_row(result))) {
    printf("%s (%s)\n", *(row+1), *row);
    ++count;
  }
  if (mysql_errno(mysql)) {
    fprintf(stderr, "Error: %s\n", mysql_error(mysql));
    ok = FALSE;
  } else {
    if (!count) printf("%s\n", norecords);
  }

  // free resultset
  mysql_free_result(result);

  return (ok ? SUCCESS : FAILURE);

}

int list_customers(void)
{
  MYSQL mysql;
  int result;

  if (!get_db_connection(&mysql)) return FAILURE;
  result = run_select_query(&mysql, "select * from customers order by abbrev", "No customers.");
  close_db_connection(&mysql);
  
  return result;
}

int add_customer(int argc, char *argv[])
{
  MYSQL mysql;
  int result;
  char key[MAX_KEYLENGTH+1];
  char name[MAX_TEXTLENGTH+1];
  char query[1000];

  if (argc != 2) {
    syntax(HELP_ADD_CUSTOMER);
    return FAILURE;
  }

  if (!get_db_connection(&mysql)) return FAILURE;

  prepare(&mysql, key, *argv++, MAX_KEYLENGTH);
  prepare(&mysql, name, *argv, MAX_TEXTLENGTH);

  sprintf(query, "insert into customers (abbrev, name) values ('%s', '%s')", key, name); 
  result = mysql_query(&mysql, query);
  if (result != 0) {
    printf("Unable to create this customer. Did you specify a unique key?\n");
  } else {
    printf("Customer added.\n");
  }
  
  close_db_connection(&mysql);
  
  return (result == 0 ? SUCCESS : FAILURE);
	
}

int del_customer(int argc, char *argv[])
{
  MYSQL mysql;
  int result;
  char key[MAX_KEYLENGTH+1];
  char query[1000];
	
  if (argc != 1) {
    syntax(HELP_DEL_CUSTOMER);
    return FAILURE;
  }

  if (!get_db_connection(&mysql)) return FAILURE;
  prepare(&mysql, key, *argv, MAX_KEYLENGTH);
 
  sprintf(query, "delete from timesheets where customer = '%s'", key);
  result = mysql_query(&mysql, query);
  if (result != 0) {
    printf("Unable to delete the timesheets for this customer: %s\n", mysql_error(&mysql));
    close_db_connection(&mysql);
    return FAILURE;
  }
  
  sprintf(query, "delete from projects where customer = '%s'", key);
  result = mysql_query(&mysql, query);
  if (result != 0) {
    printf("Unable to delete the projects for his customer: %s\n", mysql_error(&mysql));
    close_db_connection(&mysql);
    return FAILURE;
  }
  
  sprintf(query, "delete from customers where abbrev = '%s'", key);
  result = mysql_query(&mysql, query);
  if (result != 0) {
    printf("Unable to delete the customer: %s\n", mysql_error(&mysql));
    close_db_connection(&mysql);
    return FAILURE;
  }

  if (mysql_affected_rows(&mysql) < 1) {
    printf("No customers deleted.\n");
  } else {
    printf("Customer deleted.\n");
  }
  
  close_db_connection(&mysql);

  return SUCCESS;
	
}

