/*  ts.h - global include file
 *  Copyright (C) 2001 Kristof Verniers
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _TS_H
#define _TS_H

/* lengths of keys and names */

#define MAX_KEYLENGTH 20
#define MAX_TEXTLENGTH 100

/* help topics */

#define HELP_GENERAL 0
#define HELP_ADD_CUSTOMER 1
#define HELP_DEL_CUSTOMER 2
#define HELP_LIST_PROJECTS 3
#define HELP_DEL_PROJECT 4
#define HELP_ADD_PROJECT 5
#define HELP_START 6
#define HELP_STOP 7
#define HELP_LIST_TIMESHEETS 8
#define HELP_DEL_TIMESHEET 9
#define HELP_MODIFY_TIMESHEET 10

/* other defines */

#define MAX_CONFIGFILE_LINELENGTH 300

#define FAILURE 0
#define SUCCESS 1
#define NEED_HELP 2
#define NO_RECORDS 3

#define FALSE 0
#define TRUE 1

/* global variables */
struct s_config {
  char *host;
  char *user;
  char *passwd;
  char *db;
  int port;
} config;

/* prototypes for globally callable functions */

/* customers.c */
int add_customer(int argc, char *argv[]);
int del_customer(int argc, char *argv[]);
int list_customers(void);
int run_select_query(MYSQL *mysql, char *query, char *norecords);

/* timesheets.c */
int del_timesheet(int argc, char *argv[]);
int list_timesheets(int argc, char *argv[]);
int modify_timesheet(int argc, char *argv[]);
int start_timesheet(int argc, char *argv[]);
int stop_timesheet(int argc, char *argv[]);

/* projects.c */
int add_project(int argc, char *argv[]);
int del_project(int argc, char *argv[]);
int list_projects(int argc, char *argv[]);
int run_projects_query(MYSQL *mysql, char *query);

/* common.c */
void close_db_connection(MYSQL *mysql);
long get_date(MYSQL *mysql, char *date);
int get_db_connection(MYSQL *mysql);
void prepare(MYSQL *mysql, char *to, char *from, int size);
void print_padded(char *str, int length);
long returns_rows(MYSQL *mysql, char *query);

/* help.c */
void syntax(int helptopic);

/* configuration.c */
int readconfig(struct s_config *config);

#endif
